
// -------- A section standardizing cross-tabulations

// illustrate the impact of the marginal distribution in cross-tabulations with
// an example

use homogamy, clear
tab racem racef [fw=freq] if marcoh == 2010, row nofreq

// a digression on odds ratios
tab racem racef [fw=freq] if marcoh == 2010
di 122904 / 136200
di 134486 / 31956989
di (122904 / 136200)/(134486 / 31956989)

// Show how the chi-squared test deals with marginal distributions

tab racem racef [fw=freq] if marcoh==2010, exp

// Standardizing tables as the reverse of chi-squared test

stdtable racem racef [fw=freq] if marcoh == 2010

// show how to make the table look better, compare groups, and turn it into a graph

stdtable racem racef [fw=freq] if marcoh == 2010, ///
         format(%5.0f)  
		 
stdtable racem racef [fw=freq], by(marcoh) format(%5.0f)

qui stdtable racem racef [fw=freq],          ///
    by(marcoh) replace
	
tabplot racem marcoh [iw=std],               ///
    by(racef, compact note("") cols(6)       ///
	   t1title("race, wife"))                ///
    xlab( 1(1)7, angle(35) labsize(vsmall) )		 

// -------- A section on Iterative proportional fitting

// use Mata to repeatedly make all row totals a 100, and all column totals 100

use homogamy, clear
tab racem racef [fw=freq] if marcoh == 2010, matcell(data)

mata
data = st_matrix("data")

muhat = data

muhat = muhat:/rowsum(muhat):*100
end

mata
muhat = muhat:/colsum(muhat):*100
colsum(muhat)
rowsum(muhat)
end

mata
muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100

muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100

muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100

muhat = muhat:/rowsum(muhat):*100
muhat = muhat:/colsum(muhat):*100
colsum(muhat)
rowsum(muhat)
end

// a appendix showing that not all tables can be standardized

/*
        0 0 2
        1 5 2
        8 7 0
*/